@@ -55,20 +55,13 @@ def checkpoint_periodically(interval: Union[str, int, Time]) -> Callable[[State,
         raise NotImplementedError(
             f'Unknown checkpointing interval: {interval.unit}. Must be TimeUnit.EPOCH or TimeUnit.BATCH.')
 
-    last_checkpoint_batch: Optional[Time] = None
-
     def save_interval(state: State, event: Event):
-        nonlocal last_checkpoint_batch
         elapsed_duration = state.get_elapsed_duration()
         assert elapsed_duration is not None, 'elapsed_duration is set on the BATCH_CHECKPOINT and EPOCH_CHECKPOINT'
 
+        # Always checkpoint at end of training
         if elapsed_duration >= 1.0:
-            # if doing batch-wise checkpointing, and we saved a checkpoint at the batch_checkpoint event
-            # right before the epoch_checkpoint event, do not save another checkpoint at the epoch_checkpoint
-            # event if the batch count didn't increase.
-            if state.timestamp.batch != last_checkpoint_batch:
-                last_checkpoint_batch = state.timestamp.batch
-                return True
+            return True
 
         if save_event == Event.EPOCH_CHECKPOINT:
             count = state.timestamp.epoch
@@ -78,7 +71,6 @@ def checkpoint_periodically(interval: Union[str, int, Time]) -> Callable[[State,
             raise RuntimeError(f'Invalid save_event: {save_event}')
 
         if event == save_event and int(count) % int(interval) == 0:
-            last_checkpoint_batch = state.timestamp.batch
             return True
 
         return False
@@ -116,7 +108,7 @@ class CheckpointSaver(Callback):  # noqa: D101
         ... ])
 
     Args:
-        folder (str, optional): Format string for the folder where checkpoints will be saved.
+        folder (str, optional): Format string for the save_folder where checkpoints will be saved.
             Default: ``'{{run_name}}/checkpoints'``.
 
             The following format variables are available:
@@ -257,7 +249,7 @@ class CheckpointSaver(Callback):  # noqa: D101
             event.
 
         weights_only (bool): If ``True``, save only the model weights instead of the entire training state.
-            This parmeter must be ``False`` when using DeepSpeed. Default: ``False``.
+            This parameter must be ``False`` when using DeepSpeed. Default: ``False``.
 
 
         num_checkpoints_to_keep (int, optional): The number of checkpoints to keep locally. The oldest checkpoints
@@ -303,6 +295,7 @@ class CheckpointSaver(Callback):  # noqa: D101
         if not callable(save_interval):
             save_interval = checkpoint_periodically(save_interval)
         self.save_interval = save_interval
+        self.last_checkpoint_batch: Optional[Time] = None
 
         self.folder = folder
 
@@ -323,7 +316,7 @@ class CheckpointSaver(Callback):  # noqa: D101
 
     def fit_start(self, state: State, logger: Logger) -> None:
         if not self.overwrite:
-            # checks that folder contains no files with a timestamp after the current timestamp,
+            # checks that save_folder contains no files with a timestamp after the current timestamp,
             # which has potential for future conflicts.
             folder = format_name_with_dist(self.folder, state.run_name)
             ensure_folder_has_no_conflicting_files(folder, self.filename.filename, state.timestamp)
@@ -334,7 +327,7 @@ class CheckpointSaver(Callback):  # noqa: D101
             raise NotImplementedError('weights_only=True is not supported when using DeepSpeed.')
 
     def batch_checkpoint(self, state: State, logger: Logger):
-        if self.save_interval(state, Event.BATCH_CHECKPOINT):
+        if self.save_interval(state, Event.BATCH_CHECKPOINT) and self.last_checkpoint_batch != state.timestamp.batch:
             self._save_checkpoint(
                 state,
                 logger,
@@ -342,7 +335,7 @@ class CheckpointSaver(Callback):  # noqa: D101
             )
 
     def epoch_checkpoint(self, state: State, logger: Logger):
-        if self.save_interval(state, Event.EPOCH_CHECKPOINT):
+        if self.save_interval(state, Event.EPOCH_CHECKPOINT) and self.last_checkpoint_batch != state.timestamp.batch:
             self._save_checkpoint(
                 state,
                 logger,
@@ -361,6 +354,8 @@ class CheckpointSaver(Callback):  # noqa: D101
         }
 
     def _save_checkpoint(self, state: State, logger: Logger, log_level: LogLevel):
+        self.last_checkpoint_batch = state.timestamp.batch
+
         is_deepspeed = is_model_deepspeed(state.model)
 
         if is_deepspeed and '{rank}' not in self.filename.filename:
