@@ -194,6 +194,11 @@ class DataSpec:
         if isinstance(batch, (list, tuple)):
             for tensors in batch:
                 for t in ensure_tuple(tensors):
+                    if not hasattr(t, 'shape'):
+                        raise ValueError('Unable to determine the batch size, batch contains'
+                                         f'an element of type {type(t)}, which does not have a'
+                                         'shape. Please use a DataSpec and provide a'
+                                         '`get_num_samples_in_batch(your_batch) -> int` method.')
                     dim0_sizes.append(t.shape[0])
         elif isinstance(batch, dict):
             dim0_sizes = [t.shape[0] for t in batch.values()]
