@@ -2,17 +2,16 @@
 # SPDX-License-Identifier: Apache-2.0
 
 """COCO (Common Objects in Context) dataset hyperparameters."""
-import os
-from dataclasses import dataclass
+from dataclasses import asdict, dataclass
 from typing import Optional
 
 import yahp as hp
 
 from composer.core import DataSpec
-from composer.datasets.coco import COCODetection, StreamingCOCO, split_dict_fn
+from composer.datasets.coco import StreamingCOCO, build_coco_detection_dataloader, split_coco_batch
 from composer.datasets.dataset_hparams import DataLoaderHparams, DatasetHparams
 from composer.models.ssd.utils import SSDTransformer, dboxes300_coco
-from composer.utils import dist, warn_streaming_dataset_deprecation
+from composer.utils import warn_streaming_dataset_deprecation
 from composer.utils.import_helpers import MissingConditionalImportError
 
 __all__ = ['COCODatasetHparams', 'StreamingCOCOHparams']
@@ -28,46 +27,29 @@ class COCODatasetHparams(DatasetHparams):
             ``True``.
     """
 
-    is_train: bool = hp.optional('Whether to load the training data (the default) or validation data.', default=True)
-    datadir: Optional[str] = hp.optional('The path to the data directory', default=None)
+    split: str = hp.optional("Which split of the dataset to use. Either ['train', 'val'].", default='train')
+    datadir: Optional[str] = hp.optional('The path to the data directory.', default=None)
+    input_size: int = hp.optional('Input image size, keep at 300 if using with SSD300.', default=300)
+
+    def validate(self):
+        if self.datadir is None:
+            raise ValueError('datadir must specify the path to the COCO Detection dataset.')
+
+        if self.split not in ['train', 'val']:
+            raise ValueError(f"split value {self.split} must be one of ['train', 'val'].")
 
     def initialize_object(self, batch_size: int, dataloader_hparams: DataLoaderHparams):
 
-        if self.datadir is None:
-            raise ValueError('datadir is required.')
+        self.validate()
 
-        dboxes = dboxes300_coco()
-
-        input_size = 300
-        train_trans = SSDTransformer(dboxes, (input_size, input_size), val=False, num_cropping_iterations=1)
-        val_trans = SSDTransformer(dboxes, (input_size, input_size), val=True)
-        data = self.datadir
-
-        val_annotate = os.path.join(data, 'annotations/instances_val2017.json')
-        val_coco_root = os.path.join(data, 'val2017')
-
-        train_annotate = os.path.join(data, 'annotations/instances_train2017.json')
-        train_coco_root = os.path.join(data, 'train2017')
-
-        train_coco = COCODetection(train_coco_root, train_annotate, train_trans)
-        val_coco = COCODetection(val_coco_root, val_annotate, val_trans)
-
-        if self.is_train:
-            return DataSpec(dataloader=dataloader_hparams.initialize_object(
-                dataset=train_coco,
-                batch_size=batch_size,
-                sampler=dist.get_sampler(train_coco, drop_last=self.drop_last, shuffle=self.shuffle),
-                drop_last=self.drop_last,
-            ),
-                            split_batch=split_dict_fn)
-        else:
-            return DataSpec(dataloader=dataloader_hparams.initialize_object(
-                dataset=val_coco,
-                drop_last=self.drop_last,
-                batch_size=batch_size,
-                sampler=None,
-            ),
-                            split_batch=split_dict_fn)
+        return build_coco_detection_dataloader(
+            batch_size=batch_size,
+            datadir=self.datadir,  #type: ignore
+            split=self.split,
+            drop_last=self.drop_last,
+            shuffle=self.shuffle,
+            input_size=self.input_size,
+            **asdict(dataloader_hparams))
 
 
 @dataclass
@@ -126,4 +108,4 @@ class StreamingCOCOHparams(DatasetHparams):
             sampler=None,
             collate_fn=None,
         ),
-                        split_batch=split_dict_fn)
+                        split_batch=split_coco_batch)
