@@ -12,30 +12,29 @@ See :doc:`Composer Model </composer_model>` for more details.
 from composer.models.base import ComposerModel as ComposerModel
 from composer.models.bert import BERTForClassificationHparams as BERTForClassificationHparams
 from composer.models.bert import BERTHparams as BERTHparams
-from composer.models.bert import BERTModel as BERTModel
-from composer.models.classify_mnist import MNIST_Classifier as MNIST_Classifier
+from composer.models.bert import create_bert_classification as create_bert_classification
+from composer.models.bert import create_bert_mlm as create_bert_mlm
 from composer.models.classify_mnist import MnistClassifierHparams as MnistClassifierHparams
-from composer.models.deeplabv3 import ComposerDeepLabV3 as ComposerDeepLabV3
+from composer.models.classify_mnist import mnist_model as mnist_model
 from composer.models.deeplabv3 import DeepLabV3Hparams as DeepLabV3Hparams
-from composer.models.efficientnetb0 import EfficientNetB0 as EfficientNetB0
+from composer.models.deeplabv3 import composer_deeplabv3 as composer_deeplabv3
 from composer.models.efficientnetb0 import EfficientNetB0Hparams as EfficientNetB0Hparams
+from composer.models.efficientnetb0 import composer_efficientnetb0 as composer_efficientnetb0
 from composer.models.gpt2 import GPT2Hparams as GPT2Hparams
-from composer.models.gpt2 import GPT2Model as GPT2Model
+from composer.models.gpt2 import create_gpt2 as create_gpt2
 from composer.models.huggingface import HuggingFaceModel as HuggingFaceModel
 from composer.models.initializers import Initializer as Initializer
 from composer.models.model_hparams import ModelHparams as ModelHparams
-from composer.models.resnet import ComposerResNet as ComposerResNet
 from composer.models.resnet import ResNetHparams as ResNetHparams
-from composer.models.resnet_cifar import ComposerResNetCIFAR as ComposerResNetCIFAR
+from composer.models.resnet import composer_resnet as composer_resnet
 from composer.models.resnet_cifar import ResNetCIFARHparams as ResNetCIFARHparams
+from composer.models.resnet_cifar import composer_resnet_cifar as composer_resnet_cifar
 from composer.models.ssd import SSD as SSD
 from composer.models.ssd import SSDHparams as SSDHparams
 from composer.models.tasks import ComposerClassifier as ComposerClassifier
-from composer.models.timm import Timm as Timm
 from composer.models.timm import TimmHparams as TimmHparams
-from composer.models.transformer_hparams import TransformerHparams as TransformerHparams
-from composer.models.transformer_shared import ComposerTransformer as ComposerTransformer
+from composer.models.timm import composer_timm as composer_timm
 from composer.models.unet import UNet as UNet
 from composer.models.unet import UnetHparams as UnetHparams
-from composer.models.vit_small_patch16 import ViTSmallPatch16 as ViTSmallPatch16
 from composer.models.vit_small_patch16 import ViTSmallPatch16Hparams as ViTSmallPatch16Hparams
+from composer.models.vit_small_patch16 import vit_small_patch16 as vit_small_patch16
