@@ -9,7 +9,7 @@ See the :doc:`Model Card </model_cards/unet>` for more details.
 from composer.models.unet.unet import UNet as UNet
 from composer.models.unet.unet_hparams import UnetHparams as UnetHparams
 
-__all__ = ["UNet", "UnetHparams"]
+__all__ = ['UNet', 'UnetHparams']
 
 _task = 'Image Segmentation'
 _dataset = 'BRATS'
